@@ -1,6 +1,6 @@
 #!/bin/sh
 
 brew update
-brew install --HEAD libtins
+brew install libtins
 brew uninstall json-c
 brew install jsoncpp
