@@ -16,12 +16,14 @@
 #ifndef _COMMON_H
 #define _COMMON_H
 
+#define VERSION	"0.4.2"
+
 #include <map>
 
 #include <tins/tins.h>
 #include <json/json.h>
 
-#include "hop.h"
+#include "hops.h"
 
 
 /* Define/undefine USE_IP_ID_MATCHING to enable the IP ID packet matching, that
@@ -35,9 +37,7 @@ using namespace Tins;
 #define LOG_DIR		"logs"
 
 typedef uint16_t flow_id_t;
-typedef std::vector<Hop> hops_internal_t;
-typedef std::shared_ptr<hops_internal_t> hops_t;
-typedef std::map<flow_id_t, hops_t> flow_map_t;
+typedef std::map<flow_id_t, std::shared_ptr<Hops>> flow_map_t;
 
 void setupLogging();
 void shutDownLogging();
