@@ -13,8 +13,12 @@
  *
  * \sa traceroute_results.cc
  */
- 
+
+#ifndef _TRACEROUTE_RESULTS_H
+#define _TRACEROUTE_RESULTS_H
+
 #include <vector>
+#include <iostream>
 
 #include "common.h"
 #include "hop.h"
@@ -23,10 +27,12 @@
 class TracerouteResults {
 private:
 	std::shared_ptr<flow_map_t> flows_;
+	uint8_t min_ttl = 1;
 	bool compressed_;
+	bool broken_nat_;
 
 public:
-	TracerouteResults(std::shared_ptr<flow_map_t> flows);
+	TracerouteResults(std::shared_ptr<flow_map_t> flows, const uint8_t min_ttl /* = 1 */, const bool broken_nat /* = false */);
 	~TracerouteResults() { };
 	inline flow_map_t &flows() { return *flows_; }
 	std::shared_ptr<IP> match_packet(const Packet &packet);
@@ -35,3 +41,5 @@ public:
 	std::string to_json();
 };
 
+#endif /* _TRACEROUTE_RESULTS_H */
+
